# ![](dep_cube.svg)Deposit
Open source graph database engine focused on scientific data collection.

Created on 29. 4. 2013

### Author:
Peter Demján (peter.demjan@gmail.com)

Institute of Archaeology of the Czech Academy of Sciences, Prague, v.v.i.

## Installation

To install the latest version of Deposit from the Python package index, use the following command:
```
pip install deposit
```

For the GUI installer see [Deposit GUI](https://github.com/demjanp/deposit_gui/releases/latest)

## Acknowledgements: <a name="acknowledgements"></a>

Development of this software was supported by OP RDE, MEYS, under the project "Ultra-trace isotope research in social and environmental studies using accelerator mass spectrometry", Reg. No. CZ.02.1.01/0.0/0.0/16_019/0000728.

## License: <a name="license"></a>

This code is licensed under the [GNU GENERAL PUBLIC LICENSE](https://www.gnu.org/licenses/gpl-3.0.en.html) - see the [LICENSE](LICENSE) file for details
